==> syncthingtray_1.4.12.orig.tar.xz: syncthingtray-1.4.12/syncthingmodel/translations/syncthingmodel_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>Data::StatusIconSettings</name>
    <message>
        <location filename="../syncthingicons.cpp" line="229"/>
        <source>Misc. notifications</source>
        <translation>杂项通知</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="230"/>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="231"/>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="232"/>
        <source>Idle</source>
        <translation>空闲</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="233"/>
        <source>Scanning</source>
        <translation>扫描中</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="234"/>
        <source>Synchronizing</source>
        <translation>同步中</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="235"/>
        <source>Paused</source>
        <translation>已暂停</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="236"/>
        <source>Disconnected</source>
        <translation>已断连</translation>
    </message>
</context>
<context>
    <name>Data::SyncthingDeviceModel</name>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="86"/>
        <location filename="../syncthingdevicemodel.cpp" line="118"/>
        <source>ID</source>
        <translation>ID</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="88"/>
        <source>Status</source>
        <translation>状态</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="120"/>
        <source>Address</source>
        <translation>地址</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="122"/>
        <source>Connection type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="124"/>
        <source>Last seen</source>
        <translation>最后在线</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="126"/>
        <source>Compression</source>
        <translation>压缩</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="128"/>
        <source>Certificate</source>
        <translation>证书</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="130"/>
        <source>Introducer</source>
        <translation>介绍人</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="132"/>
        <source>Incoming traffic</source>
        <translation>下载流量</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="134"/>
        <source>Outgoing traffic</source>
        <translation>上传流量</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="136"/>
        <source>Version</source>
        <translation>版本</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="157"/>
        <source>local</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="157"/>
        <source>remote</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="162"/>
        <source>unknown or this device</source>
        <translation>未知或本设备</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="167"/>
        <source>none</source>
        <translation>无</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="169"/>
        <source>yes</source>
        <translation>是</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="169"/>
        <source>no</source>
        <translation>否</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="380"/>
        <source>Paused</source>
        <translation>已暂停</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="384"/>
        <source>Unknown status</source>
        <translation>未知状态</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="386"/>
        <source>This device</source>
        <translation>本设备</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="388"/>
        <source>Idle</source>
        <translation>空闲</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="390"/>
        <source>Disconnected</source>
        <translation>已断连</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="392"/>
        <source>Synchronizing (%1 %, %2)</source>
        <translation>同步中 (%1 %, %2)</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="395"/>
        <source>Synchronizing</source>
        <translation>同步中</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="397"/>
        <source>Out of sync</source>
        <translation>未同步</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="399"/>
        <source>Rejected</source>
        <translation>被拒绝</translation>
    </message>
</context>
<context>
    <name>Data::SyncthingDirectoryModel</name>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="92"/>
        <location filename="../syncthingdirectorymodel.cpp" line="124"/>
        <source>ID</source>
        <translation>ID</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="94"/>
        <source>Status</source>
        <translation>状态</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="126"/>
        <source>Path</source>
        <translation>路径</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="128"/>
        <source>Global status</source>
        <translation>全局状态</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="130"/>
        <source>Local status</source>
        <translation>本地状态</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="132"/>
        <source>Shared with</source>
        <translation>分享到</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="134"/>
        <source>Type</source>
        <translation>类型</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="136"/>
        <source>Rescan interval</source>
        <translation>重新扫描间隔</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="138"/>
        <source>Last scan</source>
        <translation>最后扫描</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="140"/>
        <source>Last file</source>
        <translation>最后更改</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="142"/>
        <source>Errors</source>
        <translation>错误</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="165"/>
        <source>not shared</source>
        <translation>未分享</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="172"/>
        <location filename="../syncthingdirectorymodel.cpp" line="175"/>
        <source>unknown</source>
        <translation>未知</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="178"/>
        <source>none</source>
        <translation>无</translation>
    </message>
    <message numerus="yes">
        <location filename="../syncthingdirectorymodel.cpp" line="184"/>
        <source>%1 item(s) out of sync</source>
        <translation>
            <numerusform>%1 项目未同步</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../syncthingdirectorymodel.cpp" line="186"/>
        <source>%1 and %2 item(s) out of sync</source>
        <translation>
            <numerusform>%1 和  %2 项目未同步</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="260"/>
        <source>Deleted at %1</source>
        <translation>于 %1 被删除</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="263"/>
        <source>Updated at %1</source>
        <translation>于 %1 更新</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="275"/>
        <source>Failed items</source>
        <translation>已失败项目</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="276"/>
        <source>Click for details</source>
        <translation>点击以获取详情</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="459"/>
        <source>Paused</source>
        <translation>已暂停</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="462"/>
        <source>Unshared</source>
        <translation>未分享</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="466"/>
        <source>Unknown status</source>
        <translation>未知状态</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="468"/>
        <source>Idle</source>
        <translation>空闲</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="470"/>
        <source>Waiting to scan</source>
        <translation>等待扫描</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="474"/>
        <source>Scanning (%1 %, %2)</source>
        <translation>扫描中 (%1 %, %2)</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="476"/>
        <source>Scanning (%1 %)</source>
        <translation>扫描中 (%1 %)</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="478"/>
        <source>Scanning</source>
        <translation>扫描中</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="480"/>
        <source>Waiting to sync</source>
        <translation>等待同步</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="482"/>
        <source>Preparing to sync</source>
        <translation>准备同步</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="484"/>
        <source>Synchronizing (%1 %)</source>
        <translation>同步中 (%1 %)</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="484"/>
        <source>Synchronizing</source>
        <translation>同步中</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="486"/>
        <source>Cleaning</source>
        <translation>清理中</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="488"/>
        <source>Waiting to clean</source>
        <translation>等待清理</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="490"/>
        <source>Out of sync</source>
        <translation>未同步</translation>
    </message>
</context>
<context>
    <name>Data::SyncthingDownloadModel</name>
    <message>
        <location filename="../syncthingdownloadmodel.cpp" line="96"/>
        <source>Dir/item</source>
        <translation>目录/项目</translation>
    </message>
    <message>
        <location filename="../syncthingdownloadmodel.cpp" line="98"/>
        <source>Progress</source>
        <translation>进度</translation>
    </message>
</context>
<context>
    <name>Data::SyncthingRecentChangesModel</name>
    <message>
        <location filename="../syncthingrecentchangesmodel.cpp" line="71"/>
        <source>Action</source>
        <translation>操作</translation>
    </message>
    <message>
        <location filename="../syncthingrecentchangesmodel.cpp" line="73"/>
        <source>Device</source>
        <translation>设备</translation>
    </message>
    <message>
        <location filename="../syncthingrecentchangesmodel.cpp" line="75"/>
        <source>Folder</source>
        <translation>目录</translation>
    </message>
    <message>
        <location filename="../syncthingrecentchangesmodel.cpp" line="77"/>
        <source>Path</source>
        <translation>路径</translation>
    </message>
    <message>
        <location filename="../syncthingrecentchangesmodel.cpp" line="119"/>
        <source>Locally</source>
        <translation>本地</translation>
    </message>
    <message>
        <location filename="../syncthingrecentchangesmodel.cpp" line="119"/>
        <source>Remotely</source>
        <translation>远程</translation>
    </message>
</context>
<context>
    <name>Data::SyncthingStatusComputionModel</name>
    <message>
        <location filename="../syncthingstatuscomputionmodel.cpp" line="37"/>
        <source>Local dir is scanning</source>
        <translation>正在扫描本地目录</translation>
    </message>
    <message>
        <location filename="../syncthingstatuscomputionmodel.cpp" line="39"/>
        <source>Local dir is synchronizing</source>
        <translation>正在同步本地目录</translation>
    </message>
    <message>
        <location filename="../syncthingstatuscomputionmodel.cpp" line="41"/>
        <source>Remote dir has outstanding progress</source>
        <translation>远程目录有未完成进度</translation>
    </message>
    <message>
        <location filename="../syncthingstatuscomputionmodel.cpp" line="43"/>
        <source>A device is paused</source>
        <translation>一个设备已暂停</translation>
    </message>
    <message>
        <location filename="../syncthingstatuscomputionmodel.cpp" line="45"/>
        <source>Local dir is out of sync</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingstatuscomputionmodel.cpp" line="47"/>
        <source>Unread notification present</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> syncthingtray_1.5.2.orig.tar.xz: syncthingtray-1.5.2/syncthingmodel/translations/syncthingmodel_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>Data::StatusIconSettings</name>
    <message>
        <location filename="../syncthingicons.cpp" line="229"/>
        <source>Misc. notifications</source>
        <translation>杂项通知</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="230"/>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="231"/>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="232"/>
        <source>Idle</source>
        <translation>空闲</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="233"/>
        <source>Scanning</source>
        <translation>扫描中</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="234"/>
        <source>Synchronizing</source>
        <translation>同步中</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="235"/>
        <source>Paused</source>
        <translation>已暂停</translation>
    </message>
    <message>
        <location filename="../syncthingicons.cpp" line="236"/>
        <source>Disconnected</source>
        <translation>已断连</translation>
    </message>
</context>
<context>
    <name>Data::SyncthingDeviceModel</name>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="86"/>
        <location filename="../syncthingdevicemodel.cpp" line="118"/>
        <source>ID</source>
        <translation>ID</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="88"/>
        <source>Status</source>
        <translation>状态</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="120"/>
        <source>Address</source>
        <translation>地址</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="122"/>
        <source>Connection type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="124"/>
        <source>Last seen</source>
        <translation>最后在线</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="126"/>
        <source>Compression</source>
        <translation>压缩</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="128"/>
        <source>Certificate</source>
        <translation>证书</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="130"/>
        <source>Introducer</source>
        <translation>介绍人</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="132"/>
        <source>Incoming traffic</source>
        <translation>下载流量</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="134"/>
        <source>Outgoing traffic</source>
        <translation>上传流量</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="136"/>
        <source>Version</source>
        <translation>版本</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="157"/>
        <source>local</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="157"/>
        <source>remote</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="162"/>
        <source>unknown or this device</source>
        <translation>未知或本设备</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="167"/>
        <source>none</source>
        <translation>无</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="169"/>
        <source>yes</source>
        <translation>是</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="169"/>
        <source>no</source>
        <translation>否</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="380"/>
        <source>Paused</source>
        <translation>已暂停</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="384"/>
        <source>Unknown status</source>
        <translation>未知状态</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="386"/>
        <source>This device</source>
        <translation>本设备</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="388"/>
        <source>Idle</source>
        <translation>空闲</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="390"/>
        <source>Disconnected</source>
        <translation>已断连</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="392"/>
        <source>Synchronizing (%1 %, %2)</source>
        <translation>同步中 (%1 %, %2)</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="395"/>
        <source>Synchronizing</source>
        <translation>同步中</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="397"/>
        <source>Out of sync</source>
        <translation>未同步</translation>
    </message>
    <message>
        <location filename="../syncthingdevicemodel.cpp" line="399"/>
        <source>Rejected</source>
        <translation>被拒绝</translation>
    </message>
</context>
<context>
    <name>Data::SyncthingDirectoryModel</name>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="92"/>
        <location filename="../syncthingdirectorymodel.cpp" line="124"/>
        <source>ID</source>
        <translation>ID</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="94"/>
        <source>Status</source>
        <translation>状态</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="126"/>
        <source>Path</source>
        <translation>路径</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="128"/>
        <source>Global status</source>
        <translation>全局状态</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="130"/>
        <source>Local status</source>
        <translation>本地状态</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="132"/>
        <source>Shared with</source>
        <translation>分享到</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="134"/>
        <source>Type</source>
        <translation>类型</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="136"/>
        <source>Rescan interval</source>
        <translation>重新扫描间隔</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="138"/>
        <source>Last scan</source>
        <translation>最后扫描</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="140"/>
        <source>Last file</source>
        <translation>最后更改</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="142"/>
        <source>Errors</source>
        <translation>错误</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="165"/>
        <source>not shared</source>
        <translation>未分享</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="172"/>
        <location filename="../syncthingdirectorymodel.cpp" line="175"/>
        <source>unknown</source>
        <translation>未知</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="178"/>
        <source>none</source>
        <translation>无</translation>
    </message>
    <message numerus="yes">
        <location filename="../syncthingdirectorymodel.cpp" line="184"/>
        <source>%1 item(s) out of sync</source>
        <translation>
            <numerusform>%1 项目未同步</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../syncthingdirectorymodel.cpp" line="186"/>
        <source>%1 and %2 item(s) out of sync</source>
        <translation>
            <numerusform>%1 和  %2 项目未同步</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="260"/>
        <source>Deleted at %1</source>
        <translation>于 %1 被删除</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="263"/>
        <source>Updated at %1</source>
        <translation>于 %1 更新</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="275"/>
        <source>Failed items</source>
        <translation>已失败项目</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="276"/>
        <source>Click for details</source>
        <translation>点击以获取详情</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="459"/>
        <source>Paused</source>
        <translation>已暂停</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="462"/>
        <source>Unshared</source>
        <translation>未分享</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="466"/>
        <source>Unknown status</source>
        <translation>未知状态</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="468"/>
        <source>Idle</source>
        <translation>空闲</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="470"/>
        <source>Waiting to scan</source>
        <translation>等待扫描</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="474"/>
        <source>Scanning (%1 %, %2)</source>
        <translation>扫描中 (%1 %, %2)</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="476"/>
        <source>Scanning (%1 %)</source>
        <translation>扫描中 (%1 %)</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="478"/>
        <source>Scanning</source>
        <translation>扫描中</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="480"/>
        <source>Waiting to sync</source>
        <translation>等待同步</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="482"/>
        <source>Preparing to sync</source>
        <translation>准备同步</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="484"/>
        <source>Synchronizing (%1 %)</source>
        <translation>同步中 (%1 %)</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="484"/>
        <source>Synchronizing</source>
        <translation>同步中</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="486"/>
        <source>Cleaning</source>
        <translation>清理中</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="488"/>
        <source>Waiting to clean</source>
        <translation>等待清理</translation>
    </message>
    <message>
        <location filename="../syncthingdirectorymodel.cpp" line="490"/>
        <source>Out of sync</source>
        <translation>未同步</translation>
    </message>
</context>
<context>
    <name>Data::SyncthingDownloadModel</name>
    <message>
        <location filename="../syncthingdownloadmodel.cpp" line="96"/>
        <source>Dir/item</source>
        <translation>目录/项目</translation>
    </message>
    <message>
        <location filename="../syncthingdownloadmodel.cpp" line="98"/>
        <source>Progress</source>
        <translation>进度</translation>
    </message>
</context>
<context>
    <name>Data::SyncthingFileModel</name>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="141"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="143"/>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="145"/>
        <source>Last modified</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingfilemodel.cpp" line="201"/>
        <source>Refresh</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Data::SyncthingRecentChangesModel</name>
    <message>
        <location filename="../syncthingrecentchangesmodel.cpp" line="71"/>
        <source>Action</source>
        <translation>操作</translation>
    </message>
    <message>
        <location filename="../syncthingrecentchangesmodel.cpp" line="73"/>
        <source>Device</source>
        <translation>设备</translation>
    </message>
    <message>
        <location filename="../syncthingrecentchangesmodel.cpp" line="75"/>
        <source>Folder</source>
        <translation>目录</translation>
    </message>
    <message>
        <location filename="../syncthingrecentchangesmodel.cpp" line="77"/>
        <source>Path</source>
        <translation>路径</translation>
    </message>
    <message>
        <location filename="../syncthingrecentchangesmodel.cpp" line="119"/>
        <source>Locally</source>
        <translation>本地</translation>
    </message>
    <message>
        <location filename="../syncthingrecentchangesmodel.cpp" line="119"/>
        <source>Remotely</source>
        <translation>远程</translation>
    </message>
</context>
<context>
    <name>Data::SyncthingStatusComputionModel</name>
    <message>
        <location filename="../syncthingstatuscomputionmodel.cpp" line="37"/>
        <source>Local dir is scanning</source>
        <translation>正在扫描本地目录</translation>
    </message>
    <message>
        <location filename="../syncthingstatuscomputionmodel.cpp" line="39"/>
        <source>Local dir is synchronizing</source>
        <translation>正在同步本地目录</translation>
    </message>
    <message>
        <location filename="../syncthingstatuscomputionmodel.cpp" line="41"/>
        <source>Remote dir has outstanding progress</source>
        <translation>远程目录有未完成进度</translation>
    </message>
    <message>
        <location filename="../syncthingstatuscomputionmodel.cpp" line="43"/>
        <source>A device is paused</source>
        <translation>一个设备已暂停</translation>
    </message>
    <message>
        <location filename="../syncthingstatuscomputionmodel.cpp" line="45"/>
        <source>Local dir is out of sync</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../syncthingstatuscomputionmodel.cpp" line="47"/>
        <source>Unread notification present</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
